#!/bin/sh
# SliTaz GNU/Linux text mode installer.
#
VERSION=beta

DRIVE_NAME=`cat /proc/sys/dev/cdrom/info | grep "drive name" | cut -f 3`
CDROM=/dev/$DRIVE_NAME
KERNEL=vmlinuz-`uname -r`

# Check if user is root.
check_root()
{
	if test $(id -u) != 0 ; then
	   echo -e "
Vous devez tre root pour continuer l'installation du systme. Arrt.
Vous pouvez utiliser 'su' suivi du mot de passe root pour devenir 
administarteur.\n"
	   exit 0
	fi
}

# Status function.
status()
{
	local CHECK=$?
	echo -en "\\033[70G[ "
	if [ $CHECK = 0 ]; then
		echo -en "\\033[1;33mOK"
	else
		echo -en "\\033[1;31mFailed"
	fi
	echo -e "\\033[0;39m ]"
}

# Basic informations.
echo ""
echo -e "\033[1mSliTaz GNU/Linux - Installateur mode texte\033[0m"
echo "================================================================================"
echo "
Bienvenue dans l'installateur en mode texte de SliTaz GNU/Linux. Il vous
suffirat de rpondre  quelques questions lors des diffrentes tapes
d'installation. Avant de commencer, assurer vous de connatre le nom de la
partitions sur laquelle vous dsirez installer SliTaz. L'installateur va
commencer par vous proposer de formater la partition cible et la monter.
Ensuite il va monter le cdrom, dcompresser les fichiers et les installer
sur la cible. Pour finir, vous aurez aussi la possibilit d'installer le 
gestionnaire de dmarrage GRUB, si besoin est. A noter que pour continuer
cette installation, vous devez avoir les droits d'administrateur root, qui
peuvent s'obtenir via la commande 'su' et le mot de passe 'root'."
echo ""
echo "================================================================================"
echo ""

echo -n "Commencer l'installation (oui/Non) ? "; read anser
if [ ! "$anser" = "oui" ]; then
	echo -e "\nArrt volontaire.\n"
	exit 0
fi

# Exit install if user is not root.
#check_root

# Ask for partitions.
echo "
Veuilliez indiquer la partition  utiliser pour installer SliTaz,
exemple : /dev/hda1."
echo ""
echo -n "Partition  utiliser ? "; read anser
if [ "$anser" == "" ]; then
	echo -e "\nPas de partition spcifie. Arrt.\n"
	exit 0
else
	TARGET_DEV=$anser
fi

# Mkfs if needed/wanted.
echo "
SliTaz va tre install sur la partition : $TARGET_DEV"
echo ""
echo -n "Faut t'il formater la partition en ext3 (oui/Non) ? "; read anser
if [ "$anser" == "oui" ]; then
	mkfs.ext3 $TARGET_DEV
else
	echo "Le systme de fichiers dj prsent sera utilis..."
fi

# Mount.
echo "Montage de la partitions et du cdrom..."
mkdir -p /mnt/target /media/cdrom
mount $TARGET_DEV /mnt/target
mount -t iso9660 $CDROM /media/cdrom

# Copy and install.
echo "Copie des fichiers ncessaires..."
mkdir -p /mnt/target/boot
cp /media/cdrom/boot/bzImage /mnt/target/boot/$KERNEL
cp /media/cdrom/boot/rootfs.gz /mnt/target

# Extract
echo "Extraction du systme de fichiers racine (rootfs)..."
cd /mnt/target
gzip -d rootfs.gz && cpio -id < rootfs
rm rootfs init

# End info
echo ""
echo -e "\033[1mInstallation termine\033[0m
================================================================================

Avant de redmarrer sur votre nouveau systme SliTaz GNU/Linux, veuillez vous
assurer qu'un gestionnaire de dmarrage est bien install. Si ce n'est pas le
cas vous pouvez lancer la commande (en modifiant 'hda' en fonction de votre
systme) :

    # grub-install --root-directory=/mnt/target /dev/hda

Les lignes qui feront dmarrer SliTaz via le fichier de configuration de GRUB
/boot/grub/menu.lst, en modifiant root(hd0,0) en fonction de votre systme:

    title  SliTaz GNU/Linux (cooking) (Kernel $KERNEL)
           root(hd0,0)
           kernel /boot/$KERNEL root=$TARGET_DEV

================================================================================"
echo ""
